typedef string dateTime
typedef string anyURI

struct ObjectRef {
    1: i32 id,
    2: string name,
}

struct AccountData {
    1: i32 id,
    2: string name,
    3: string real_name,
    4: string email
}

struct AttachmentData {
    1: i32 id,
    2: string filename,
    3: i32 size,
    4: string content_type,
    5: dateTime date_submitted,
    6: anyURI download_url
}

struct RelationshipData {
    1: i32 id,
    2: ObjectRef type,
    3: i32 target_id
}

struct IssueNoteData {
    1: i32 id,
    2: AccountData reporter,
    3: string text,
    4: ObjectRef view_state,
    5: dateTime date_submitted,
    6: dateTime last_modified
}

struct CustomFieldValueForIssueData {
    1: ObjectRef field,
    2: string value
}

struct IssueData {
    1: i32 id,
    2: ObjectRef view_state,
    3: dateTime last_updated,

    4: ObjectRef project,
    5: string category,
    6: ObjectRef priority,
    7: ObjectRef severity,
    8: ObjectRef status,

    9: AccountData reporter,
    10: string summary,
    11: string version,
    12: string build,
    13: string platform,
    14: string os,
    15: string os_build,
    16: ObjectRef reproducibility,
    17: dateTime date_submitted,

    18: i32 sponsorship_total,

    19: AccountData handler,
    20: ObjectRef projection,
    21: ObjectRef eta,

    22: ObjectRef resolution,
    23: string fixed_in_version,

    24: string description,
    25: string steps_to_reproduce,
    26: string additional_information,

    27: list<AttachmentData> attachments,
    28: list<RelationshipData> relationships,
    29: list<IssueNoteData> notes,
    30: list<CustomFieldValueForIssueData> custom_fields
}


exception ThriftException {
    1: string faultcode,
    2: string faultactor,
    3: string faultstring
}

service MantisThrift {
    string mt_version(),

    list<ObjectRef> mt_enum_status(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_priorities(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_severities(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_reproducibilities(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_projections(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_etas(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_resolutions(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_access_levels(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_project_status(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_project_view_states(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_view_states(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_custom_field_types(1:string username, 2:string password) throws (1:ThriftException te),
    list<ObjectRef> mt_enum_get(1:string username, 2:string password, 3:string enumeration) throws (1:ThriftException te),

    bool mt_issue_exists(1:string username, 2:string password, 3:i32 issue_id) throws (1:ThriftException te),
    IssueData mt_issue_get(1:string username, 2:string password, 3:i32 issue_id) throws (1:ThriftException te),
    i32 mt_issue_get_biggest_id(1:string username, 2:string password, 3:i32 project_id) throws (1:ThriftException te),
    i32 mt_issue_get_id_from_summary(1:string username, 2:string password, 3:string summary) throws (1:ThriftException te),
    i32 mt_issue_add(1:string username, 2:string password, 3:IssueData issue) throws (1:ThriftException te),
    bool mt_issue_update(1:string username, 2:string password, 3:i32 issue_id, 4:IssueData issue) throws (1:ThriftException te),
    bool mt_issue_delete(1:string username, 2:string password, 3:i32 issue_id) throws (1:ThriftException te),
    i32 mt_issue_note_add(1:string username, 2:string password, 3:i32 issue_id, 4:IssueNoteData note) throws (1:ThriftException te),
    bool mt_issue_note_delete(1:string username, 2:string password, 3:i32 note_id) throws (1:ThriftException te),
    i32 mt_issue_relationship_add(1:string username, 2:string password, 3:i32 issue_id, 4:RelationshipData relationship) throws (1:ThriftException te),
    bool mt_issue_relationship_delete(1:string username, 2:string password, 3:i32 issue_id, 4:i32 relationship_id) throws (1:ThriftException te),

    i32 mt_issue_attachment_add(1:string username, 2:string password, 3:i32 issue_id, 4:string name, 5:string file_type, 6:binary content ) throws (1:ThriftException te),
    bool mt_issue_attachment_delete(1:string username, 2:string password, 3:i32 issue_attachment_id ) throws (1:ThriftException te),
    binary mt_issue_attachment_get(1:string username, 2:string password, 3:i32 issue_attachment_id) throws (1:ThriftException te),
}
